@@ -72,9 +72,9 @@ class HTTP_Client:
         else:
             raise safeGraphError(f'''*** Unrecognized DateTime! {value}\n must be either one list/str/dict''')
 
-    async def main_runner(self, query):
+    async def main_runner(self, query, timeout=200): # on default waits 2 mins before timeout error 
         self.ct+=1
-        transport = AIOHTTPTransport(url=self.url, headers=self.headers)
+        transport = AIOHTTPTransport(url=self.url, headers=self.headers, timeout=timeout)
         async with gql_Client(
             transport=transport, fetch_schema_from_transport=True,
         ) as session:
@@ -455,12 +455,10 @@ class HTTP_Client:
             for place in result['batch_lookup']:
                 dict_ = {}
                 for j in data_type:
-                    print(place)
                     try:
                         dict_.update(place[j])
                         dict_['placekey'] = (place['placekey'])
                     except (TypeError, KeyError):
-                        import pdb;pdb.set_trace()
                         # 'safegraph_weekly_patterns': None
                         pass
                 data_frame.append(dict_)
@@ -752,21 +750,38 @@ When querying by location & address, it's necessary to have at least the followi
                     else:
                         raise safeGraphError(f'return_type "{return_type}" does not exist')
                 except Exception as e:
-                    try:
-                        if result.errors[0]['message'].startswith("Maximum 'after' value exceeded"):
-                            _max_after = True
-                            break
-                    except:
-                        pass
-                    for err in e.errors:
-                        if err["message"] == "Maximum 'after' value exceeded, use 'last_seen_placekey' to get next page. (max_offset=5000)":
-                            # {'message': "Maximum 'after' value exceeded, use 'last_seen_placekey' to get next page. (max_offset=5000)", 'path': ['search'], 'locations': [{'line': 2, 'column': 3}]}
-                            _max_after = True
-                            break
+                    if type(e) == TypeError:
+                        # print("result","result", result, e, e == "'TimeoutError' object is not subscriptable")
+                        if e == "'TimeoutError' object is not subscriptable":
+                            print(408, "Timeout on request")
+                            continue
+                        # try:
+                        if result.code == 408:
+                            print(result.code, "Timeout on request")
+                            continue
+                        if result.code == 429:
+                            print(result.code, "Too many requests")
+                        continue
+                        # except AttributeError:
+                        #     print("AttributeError", e, result)
+                        #     import pdb;pdb.set_trace()
+                        #     continue
+                    elif type(e) == TimeoutError:
+                        print(408, "Timeout on request")
+                        continue
+                    elif "errors" in result.keys():
+                        for err in e.errors:
+                            if err["message"] == "Maximum 'after' value exceeded, use 'last_seen_placekey' to get next page. (max_offset=5000)":
+                                # {'message': "Maximum 'after' value exceeded, use 'last_seen_placekey' to get next page. (max_offset=5000)", 'path': ['search'], 'locations': [{'line': 2, 'column': 3}]}
+                                _max_after = True
+                                print(err["message"])
+                                break
                 try:
                     output+=result['search']
                 except UnboundLocalError:
                     break
+                except TypeError:
+                    continue
                 after += first
             for out in output:
                 dict_ = {}
